from gau_python.providers.otx import get_urls_otx
from gau_python.providers.wayback import get_urls_wayback
from gau_python.providers.commoncrawl import get_urls_commoncrawl
from gau_python.main import get_all_urls



import json
import logging

import requests


def get_urls_commoncrawl(domain, num_of_api_urls):
    api_urls = get_available_apis()
    urls = []
    page = 1

    if num_of_api_urls > len(api_urls):
        raise Exception("Total number of api urls is less than number to check ")

    for i in range(num_of_api_urls):
        try:
            while True:
                request_url = api_urls[i] + f'?url={domain}/*&output=json&fl=url&page={str(page)}'
                logging.info(f'GET {request_url}')
                response = requests.get(url=request_url)
                if response.status_code == 200:
                    for item in response.text.split('\n'):
                        try:
                            item_json = json.loads(item)
                            urls.append(str(item_json["url"]))
                        except json.JSONDecodeError:
                            logging.warning("JSON Error: Probably trying to decode empty item")
                    page += 1
                else:
                    break
        except requests.exceptions.Timeout:
            logging.error("requests.exceptions.Timeout: Timeout")
        except requests.exceptions.TooManyRedirects:
            logging.error("requests.exceptions.TooManyRedirects: Too many redirects. Try a different URL.")
        except requests.exceptions.RequestException:
            logging.error("requests.exceptions.RequestException")
        page = 1

    return urls


def get_available_apis():
    request_url = 'http://index.commoncrawl.org/collinfo.json'
    response = requests.get(url=request_url)
    response_json = json.loads(response.text)

    api_urls = []
    for api_url in response_json:
        api_urls.append(api_url["cdx-api"])

    return api_urls



import json
import logging

import requests

base_url = 'https://otx.alienvault.com/api/v1/indicators/hostname'


def get_urls_otx(domain):
    urls = []
    page = 1
    try:
        while True:
            request_url = base_url + f'/{domain}/url_list?limit=100&page={str(page)}'
            logging.info(f'GET {request_url}')
            response = requests.get(url=request_url)
            response_json = json.loads(response.text)

            for url_item in response_json["url_list"]:
                urls.append(str(url_item["url"]))
            if response_json['has_next']:
                page += 1
            else:
                break

    except requests.exceptions.Timeout:
        logging.error("requests.exceptions.Timeout: Timeout")
    except requests.exceptions.TooManyRedirects:
        logging.error("requests.exceptions.TooManyRedirects: Too many redirects. Try a different URL.")
    except requests.exceptions.RequestException:
        logging.error("requests.exceptions.RequestException")

    return urls



import logging

from gau_python.providers.commoncrawl import get_urls_commoncrawl
from gau_python.providers.otx import get_urls_otx
from gau_python.providers.wayback import get_urls_wayback


def get_all_urls(domain, num_of_api_urls=1, logging_level=logging.ERROR):
    logging.basicConfig(format='%(asctime)s: gau-python %(levelname)s: %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p',
                        level=logging_level)

    urls = get_urls_otx(domain) + get_urls_commoncrawl(domain=domain, num_of_api_urls=num_of_api_urls) + get_urls_wayback(domain)
    urls.sort()

    return urls



import json
import logging

import requests

base_url = "https://web.archive.org/cdx/search/cdx"


def get_urls_wayback(domain):
    urls = []
    page = 0
    try:
        while True:
            request_url = base_url + f'?url={domain}/*&output=json&collapse=urlkey&fl=original&page={page}'
            logging.info(f'GET {request_url}')
            response = requests.get(url=request_url)
            if len(response.text) > 0:
                response_json = json.loads(response.text)
                for url in response_json:
                    urls.append(str(url[0]))
                page += 1
            else:
                break

    except requests.exceptions.Timeout:
        logging.error("requests.exceptions.Timeout: Timeout")
    except requests.exceptions.TooManyRedirects:
        logging.error("requests.exceptions.TooManyRedirects: Too many redirects. Try a different URL.")
    except requests.exceptions.RequestException:
        logging.error("requests.exceptions.RequestException")

    return urls
